@@ -109,13 +109,7 @@ pub(crate) fn truthy(value: Value) -> bool {
 }
 
 fn error(value: Value) -> Result<Value> {
-    match value {
-        Value::String(s) => Err(QueryExecutionError::UserDefinedError((*s).clone())),
-        value => Err(QueryExecutionError::UserDefinedError(format!(
-            "{:?}",
-            value
-        ))),
-    }
+    return Err(QueryExecutionError::UserDefinedError(value));
 }
 
 fn error1(_: Value, arg: Value) -> Result<Value> {
@@ -258,6 +252,7 @@ pub(crate) fn group_by(context: Value) -> Result<Value> {
 
 fn indices(context: Value, s: Value) -> Result<Value> {
     let ret = match (context, s) {
+        (Value::Null, _) => Value::Null,
         (Value::String(lhs), Value::String(rhs)) => Array::from_vec(if rhs.is_empty() {
             vec![]
         } else {
