@@ -45,6 +45,20 @@ test!(
     "#
 );
 
+test!(
+    format_csv_tsv,
+    r#"
+    [1, "foo", null, 2, nan, "foo,\n\"bar\"\tbaz"] | @csv, @tsv
+    "#,
+    r#"
+    null
+    "#,
+    r#"
+    "1,\"foo\",,2,,\"foo,\n\"\"bar\"\"\tbaz\""
+    "1\tfoo\t\t2\t\tfoo,\\n\"bar\"\\tbaz"
+    "#
+);
+
 test!(
     boolean_comparison,
     r#"
@@ -480,3 +494,41 @@ test!(
     3
     "#
 );
+
+test!(
+    index_and_slice_with_large_numbers,
+    r#"
+    .[1e300], .[-1e300], .[-1e300:], .[1e300:], .[:-1e300], .[:1e300], .[-1e300:1e300], .[1e300:-1e300]
+    "#,
+    r#"
+    [0,1,2]
+    "#,
+    r#"
+    null
+    null
+    [0,1,2]
+    []
+    []
+    [0,1,2]
+    [0,1,2]
+    []
+    "#
+);
+
+test!(
+    modulo_floating_point_numbers,
+    r#"
+    (3.5, -6.5) % (1.0, -2.5, 8.5)
+    "#,
+    r#"
+    null
+    "#,
+    r#"
+    0
+    0
+    1
+    0
+    3
+    -6
+    "#
+);
